FormatType enum

The format of the WAV audio data on disk.

Inheritance
Available extensions

Values

pcm8 → const FormatType

Unsigned 8-bit PCM.

pcm16 → const FormatType

Signed 16-bit PCM.

pcm24 → const FormatType

Signed 24-bit PCM.

pcm32 → const FormatType

Signed 32-bit PCM.

float32 → const FormatType

32-bit IEEE Floating-Point.

float64 → const FormatType

64-bit IEEE Floating-Point.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FormatType>
A constant List of the values in this enum, in order of their declaration.