currentSample property
int
get
currentSample
Gets the current sample frame index location of the reader.
Implementation
int get currentSample => _currentSample;
Gets the current sample frame index location of the reader.
int get currentSample => _currentSample;