WavWriter class

A class to stream/write audio samples to a wav file on disk.

Constructors

WavWriter(RandomAccessFile file, WavFormat format, StorageType storageType, {bool extensible = true, bool bigEndian = false, ListInfo? info})

Properties

bigEndian bool
final
extensible bool
final
file RandomAccessFile
final
format WavFormat
final
hashCode int
The hash code for this object.
no setterinherited
info ListInfo?
final
numEndianess Endian
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageType StorageType
final

Methods

close() → void
Finalize the wav file by rewriting the header with the total length.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(IWavSamplesStorage chunk) → void
Append audio chunks to the end of the data chunk.

Operators

operator ==(Object other) bool
The equality operator.
inherited