RandomAccessFileHeaderInput class

A WavHeaderInput implementation wrapping a RandomAccessFile.

Implemented types

Properties

file RandomAccessFile
final
hashCode int
The hash code for this object.
no setterinherited
length int
The total size of the input source.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getByteData(int offset, int length) ByteData
Returns a ByteData view of the raw bytes starting at offset for length bytes.
override
getUint32(int offset, Endian endian) int
Reads a 32-bit unsigned integer at offset using the specified endian byte order.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited