RandomAccessFileHeaderInput class
A WavHeaderInput implementation wrapping a RandomAccessFile.
- Implemented types
Constructors
Properties
- file → RandomAccessFile
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
The total size of the input source.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getByteData(
int offset, int length) → ByteData -
Returns a ByteData view of the raw bytes starting at
offsetforlengthbytes.override -
getUint32(
int offset, Endian endian) → int -
Reads a 32-bit unsigned integer at
offsetusing the specifiedendianbyte order.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited